==> zio-aws-route53_2.13-7.28.29.7-sources.jar: zio/aws/route53/model/Tag.scala <==
package zio.aws.route53.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.route53.model.primitives.{TagValue, TagKey}
import scala.jdk.CollectionConverters._
final case class Tag(
    key: Optional[TagKey] = Optional.Absent,
    value: Optional[TagValue] = Optional.Absent
) {
  def buildAwsValue(): software.amazon.awssdk.services.route53.model.Tag = {
    import Tag.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53.model.Tag
      .builder()
      .optionallyWith(key.map(value => TagKey.unwrap(value): java.lang.String))(
        _.key
      )
      .optionallyWith(
        value.map(value => TagValue.unwrap(value): java.lang.String)
      )(_.value)
      .build()
  }
  def asReadOnly: zio.aws.route53.model.Tag.ReadOnly =
    zio.aws.route53.model.Tag.wrap(buildAwsValue())
}
object Tag {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.route53.model.Tag] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53.model.Tag = zio.aws.route53.model
      .Tag(key.map(value => value), value.map(value => value))
    def key: Optional[TagKey]
    def value: Optional[TagValue]
    def getKey: ZIO[Any, AwsError, TagKey] =
      AwsError.unwrapOptionField("key", key)
    def getValue: ZIO[Any, AwsError, TagValue] =
      AwsError.unwrapOptionField("value", value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53.model.Tag
  ) extends zio.aws.route53.model.Tag.ReadOnly {
    override val key: Optional[TagKey] = zio.aws.core.internal
      .optionalFromNullable(impl.key())
      .map(value => zio.aws.route53.model.primitives.TagKey(value))
    override val value: Optional[TagValue] = zio.aws.core.internal
      .optionalFromNullable(impl.value())
      .map(value => zio.aws.route53.model.primitives.TagValue(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53.model.Tag
  ): zio.aws.route53.model.Tag.ReadOnly = new Wrapper(impl)
}

==> zio-aws-route53_3-5.17.116.1-sources.jar: zio/aws/route53/model/Tag.scala <==
package zio.aws.route53.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.route53.model.primitives.{TagValue, TagKey}
import scala.jdk.CollectionConverters.*
final case class Tag(
    key: Option[TagKey] = None,
    value: Option[TagValue] = None
) {
  def buildAwsValue(): software.amazon.awssdk.services.route53.model.Tag = {
    import Tag.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53.model.Tag
      .builder()
      .optionallyWith(key.map(value => TagKey.unwrap(value): java.lang.String))(
        _.key
      )
      .optionallyWith(
        value.map(value => TagValue.unwrap(value): java.lang.String)
      )(_.value)
      .build()
  }
  def asReadOnly: zio.aws.route53.model.Tag.ReadOnly =
    zio.aws.route53.model.Tag.wrap(buildAwsValue())
}
object Tag {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.route53.model.Tag] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53.model.Tag = zio.aws.route53.model
      .Tag(key.map(value => value), value.map(value => value))
    def key: Option[TagKey]
    def value: Option[TagValue]
    def getKey: ZIO[Any, AwsError, TagKey] =
      AwsError.unwrapOptionField("key", key)
    def getValue: ZIO[Any, AwsError, TagValue] =
      AwsError.unwrapOptionField("value", value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53.model.Tag
  ) extends zio.aws.route53.model.Tag.ReadOnly {
    override val key: Option[TagKey] = scala
      .Option(impl.key())
      .map(value => zio.aws.route53.model.primitives.TagKey(value))
    override val value: Option[TagValue] = scala
      .Option(impl.value())
      .map(value => zio.aws.route53.model.primitives.TagValue(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53.model.Tag
  ): zio.aws.route53.model.Tag.ReadOnly = new Wrapper(impl)
}
